
# [caseydelorme.com](https://github.com/cdelorme/caseydelorme.com)

This site began with the concept of a simplified static site generator.  As a result I built [staticmd](staticmd.html) first.

The goal of this site was to replace a traditional dynamic system with raw static content.  I would then replace (and redirect) my [old site](http://www.cdelorme.com) with this one.


## design considerations

One major consideration was taking advantage of content delivery using AWS S3 and CloudFront services for any static or binary contents.  This provides a significantly greater degree of scalability, in that I can create as many servers as necessary to deliver the websites static content, while binary/static files all come from one place.

Right now that includes images, fonts, and some static third-party css and javascript.  Because my own css and javascript are still under construction it made sense to include them using git-hash-versioning.  This ensures the browser won't cache incorrectly.  _In the future I could use that versioning to minify, name, and upload my content to S3 and use the CDN exclusively for all versions._

Another advantage to moving away from a dynamic website is that when dealing with basic static html we can enable simple caching directly through nginx without concern for other layers; there is no CMS to contend with or concern for "immediately up-to-date" contents.

I decided to implement `https` because I intend to use the domain for experiments from time to time, and also [because it's free](https://www.startssl.com/).

Finally, I am using git, as well as github, as a means of version control for my website now.  This allows me to enable a simple cronjob to pull changes hourly, and know that I can update my site from any computer by simply pushing new static html to the github repository.  This also means I have a backup, and a means of distribution/deployment in a way that is scalable.


## future plans

I have a list of enhancements I'd like to add in the future, which may involve changes to my `staticmd` project as well:

- move css and javascript to cdn
- implement date tracking
- improved indexing, navigation, and primary index file identification

For any binary file or large file it would make sense to keep it out of the repository and to use a content delivery network.  However, for the builtin css and javascript, being so small, there isn't a problem having as many copies as there are machines with the content.  Further, if I needed to scale the deployment mechanism uses the repository and should always have the latest copy of content.  That said, using some sort of task automator, like [grunt](http://gruntjs.com/), would allow me to minify, name, and upload my javascript and css to the same AWS CloudFront I use for other files.  If anything it would be good practice for any future sites I choose to work on.

I would like to be able to identify when a file was created and last updated, and provide these either below the first header, or at the bottom of the content.  For now, the date created and updated is technically accessible in the repository, but readers won't want to be bothered to look that far, so I can manually add dates for the time being.  The concerns here include whether the file system will correctly track the date created and modified of a file, especially if the files consist of a fresh clone.

I took shortcuts with the current implementation of staticmd's index builder and identification.  Ideally I wanted to go the github route and work with `readme.md` as the **primary** index file.  However, to conditionally pick between two possible index files adds a bunch more complication, so I ended up sticking with one.  In the future I would like to correct this, and improve how I generate the indexes and main navigation as well.  Things like sort-by-date-order, folders-first, and intelligently ignoring index pages (again complications if two files could both potentially be an index page).

##### _written on 2014-12-22_
